==> honeybadger-java-2.0.0-sources.jar: io/honeybadger/reporter/config/ConfigContext.java <==
package io.honeybadger.reporter.config;

import java.net.URI;
import java.util.Set;

/**
 * Interface defining the common properties needed to configure a
 * {@link io.honeybadger.reporter.NoticeReporter}.
 *
 * @author <a href="https://github.com/dekobon">Elijah Zupancic</a>
 * @since 1.0.10
 */
public interface ConfigContext {
    /** @return name of environment */
    String getEnvironment();

    /** @return Honeybadger URL to use */
    URI getHoneybadgerUrl();

    /** @return Honeybadger API key to use */
    String getApiKey();

    /** @return Set of system properties to not include */
    Set<String> getExcludedSysProps();

    /** @return Set of parameters to not include */
    Set<String> getExcludedParams();

    /** @return Set of exception classes to ignore */
    Set<String> getExcludedClasses();

    /** @return String that maps a package to an application */
    String getApplicationPackage();

    /** @return Honeybadger Read API key */
    String getHoneybadgerReadApiKey();

    /** @return Do we display the feedback form? */
    Boolean isFeedbackFormDisplayed();

    /** @return The path to the feedback form template */
    String getFeedbackFormPath();

    /** @return Host of proxy server to send traffic through */
    String getHttpProxyHost();

    /** @return Port of proxy server to send traffic through */
    Integer getHttpProxyPort();

    /** @return Optional configuration parameter to adjust number of attempts to retry sending an error
     * report in the event of a network timeout or other transmission exception. Defaults to 3. */
    Integer getMaximumErrorReportingRetries();
}

==> honeybadger-java-2.1.0-sources.jar: io/honeybadger/reporter/config/ConfigContext.java <==
package io.honeybadger.reporter.config;

import java.net.URI;
import java.util.Set;

/**
 * Interface defining the common properties needed to configure a
 * {@link io.honeybadger.reporter.NoticeReporter}.
 *
 * @author <a href="https://github.com/dekobon">Elijah Zupancic</a>
 * @since 1.0.10
 */
public interface ConfigContext {
    /** @return name of environment */
    String getEnvironment();

    /** @return Honeybadger URL to use */
    URI getHoneybadgerUrl();

    /** @return Honeybadger API key to use */
    String getApiKey();

    /** @return Set of system properties to not include */
    Set<String> getExcludedSysProps();

    /** @return Set of parameters to not include */
    Set<String> getExcludedParams();

    /** @return Set of exception classes to ignore */
    Set<String> getExcludedClasses();

    /** @return String that maps a package to an application */
    String getApplicationPackage();

    /** @return Honeybadger Read API key */
    String getHoneybadgerReadApiKey();

    /** @return Do we display the feedback form? */
    Boolean isFeedbackFormDisplayed();

    /** @return The path to the feedback form template */
    String getFeedbackFormPath();

    /** @return Host of proxy server to send traffic through */
    String getHttpProxyHost();

    /** @return Port of proxy server to send traffic through */
    Integer getHttpProxyPort();

    /** @return Optional configuration parameter to adjust number of attempts to retry sending an error
     * report in the event of a network timeout or other transmission exception. Defaults to 3. */
    Integer getMaximumErrorReportingRetries();

    /** @return Timeout for socket connection within HTTP client */
    Integer getSocketTimeout();

    /** @return Timeout for initial connect within HTTP client */
    Integer getConnectTimeout();
}
